import {FC, useCallback, useEffect, useState} from "react";
import {View} from "@tarojs/components";
import {brandApi, BrandRecord, Meeting} from "@/api";
import styles from './list.module.scss'
import Taro, {useReachBottom} from "@tarojs/taro";
import Empty from "@/components/empty/empty";
import {formatDate} from "@/utils/time";
import brandView from "@/pages/brand/list/components/BrandView";

const MeetingsConfig: FC = () => {
  const [page, setPage] = useState(1)
  const [brands, setBrands] = useState<BrandRecord[]>([])
  const [total, setTotal] = useState(0)

  useEffect(() => {
    getData()
  }, [page])

  const getData = useCallback( async () => {
    try {
      // const res = await brandApi.list(1, 10)
      // setTotal(res.total)
      // setBrands([
      //   ...res.data
      // ])
    } catch (e) {
    }
  }, [page])

  function del(id: number, index: number) {
    try {
      Taro.showModal({
        title: '确定删除',
        async success({confirm}) {
          if (confirm) {
            await meetingAPi.del(id)

            const oldMeeting: Meeting[] = JSON.parse(JSON.stringify(brandView))
            oldMeeting.splice(index, 1)
            setBrands(oldMeeting)
          }
        }
      })
    } catch (e) {
    }
  }

  function jumpInfo(item: Meeting) {
    if (Date.now() > item.estimate_end_time || item.status > 0) {
      return
    }
    Taro.navigateTo({url: `/pages/manage/spotMeeting/spotMeeting?id=${item.id}`})
  }

  useReachBottom(useCallback(() => {
    if (brands?.length < total) {
      setPage(page + 1)
    }
  }, [total, brands]))



  return (
    <View className='p-2'>

      {
        brands.length ?
          brands.map((d, index) => <View className={styles.meeting} key={d.id}>
            <View className={styles.title} onClick={() => jumpInfo(d)}>
              <View className='font-weight mb-1'>{d.name}</View>
              <View>{formatDate(new Date(d.estimate_start_time), "MM-dd")} 至 {formatDate(new Date(d.estimate_start_time), "MM-dd")}</View>
              {
                (Date.now() > d.estimate_end_time || d.status > 1) && <View className={styles.overdue}>
                  {d.status > 1 ? '已结束' : "已过期"}
                </View>
              }
            </View>
            <View className={styles.del} onClick={() => del(d.id, index)}>删除</View>
          </View>)
          : <Empty name='空空如也'/>
      }
    </View>
  )
}

export default MeetingsConfig
